[next] telepathy-glib: rename tp_stream_tube_channel_dup_parameters_vardict()

Guillaume Desmottes gdesmott at kemper.freedesktop.org
Thu Feb 27 06:07:35 PST 2014


Module: telepathy-glib
Branch: next
Commit: 2cc9fb0a198eab1c77bad62f17686a888d58fed5
URL:    http://cgit.freedesktop.org/telepathy/telepathy-glib/commit/?id=2cc9fb0a198eab1c77bad62f17686a888d58fed5

Author: Guillaume Desmottes <guillaume.desmottes at collabora.co.uk>
Date:   Wed Feb 19 10:36:00 2014 +0100

rename tp_stream_tube_channel_dup_parameters_vardict()

---

 docs/reference/telepathy-glib/telepathy-glib-sections.txt |    2 +-
 telepathy-glib/stream-tube-channel.c                      |    8 ++++----
 telepathy-glib/stream-tube-channel.h                      |    2 +-
 tests/dbus/stream-tube.c                                  |    6 +++---
 4 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/docs/reference/telepathy-glib/telepathy-glib-sections.txt b/docs/reference/telepathy-glib/telepathy-glib-sections.txt
index 412a6a2..1172305 100644
--- a/docs/reference/telepathy-glib/telepathy-glib-sections.txt
+++ b/docs/reference/telepathy-glib/telepathy-glib-sections.txt
@@ -5147,7 +5147,7 @@ TpStreamTubeChannel
 TpStreamTubeChannelClass
 tp_stream_tube_channel_accept_async
 tp_stream_tube_channel_accept_finish
-tp_stream_tube_channel_dup_parameters_vardict
+tp_stream_tube_channel_dup_parameters
 tp_stream_tube_channel_get_service
 tp_stream_tube_channel_offer_async
 tp_stream_tube_channel_offer_finish
diff --git a/telepathy-glib/stream-tube-channel.h b/telepathy-glib/stream-tube-channel.h
index 329fdb5..e21ca8b 100644
--- a/telepathy-glib/stream-tube-channel.h
+++ b/telepathy-glib/stream-tube-channel.h
@@ -62,7 +62,7 @@ GType tp_stream_tube_channel_get_type (void);
 const gchar * tp_stream_tube_channel_get_service (TpStreamTubeChannel *self);
 
 _TP_AVAILABLE_IN_0_20
-GVariant *tp_stream_tube_channel_dup_parameters_vardict (
+GVariant *tp_stream_tube_channel_dup_parameters (
     TpStreamTubeChannel *self);
 
 /* Incoming tube methods */
diff --git a/tests/dbus/stream-tube.c b/tests/dbus/stream-tube.c
index 4d9bf27..d4f06d5 100644
--- a/tests/dbus/stream-tube.c
+++ b/tests/dbus/stream-tube.c
@@ -272,7 +272,7 @@ test_properties (Test *test,
   g_free (service);
 
   /* Parameters */
-  parameters_vardict = tp_stream_tube_channel_dup_parameters_vardict (
+  parameters_vardict = tp_stream_tube_channel_dup_parameters (
       test->tube);
   /* NULL as the tube has not been offered yet */
   g_assert (parameters_vardict == NULL);
@@ -286,7 +286,7 @@ test_properties (Test *test,
       TP_SOCKET_ACCESS_CONTROL_LOCALHOST, FALSE);
 
   /* Parameters */
-  parameters_vardict = tp_stream_tube_channel_dup_parameters_vardict (
+  parameters_vardict = tp_stream_tube_channel_dup_parameters (
       test->tube);
   check_parameters (parameters_vardict);
   g_variant_unref (parameters_vardict);
@@ -584,7 +584,7 @@ test_offer_success (Test *test,
   tp_stream_tube_channel_offer_async (test->tube, params, tube_offer_cb, test);
   g_hash_table_unref (params);
 
-  parameters_vardict = tp_stream_tube_channel_dup_parameters_vardict (
+  parameters_vardict = tp_stream_tube_channel_dup_parameters (
       test->tube);
   check_parameters (parameters_vardict);
   g_variant_unref (parameters_vardict);



More information about the telepathy-commits mailing list
diff --git a/telepathy-glib/stream-tube-channel.c b/telepathy-glib/stream-tube-channel.c
index c0e45b6..f786856 100644
--- a/telepathy-glib/stream-tube-channel.c
+++ b/telepathy-glib/stream-tube-channel.c
@@ -306,7 +306,7 @@ tp_stream_tube_channel_get_property (GObject *object,
 
       case PROP_PARAMETERS_VARDICT:
         g_value_take_variant (value,
-            tp_stream_tube_channel_dup_parameters_vardict (self));
+            tp_stream_tube_channel_dup_parameters (self));
         break;
 
       default:
@@ -453,7 +453,7 @@ tp_stream_tube_channel_class_init (TpStreamTubeChannelClass *klass)
    *
    * In high-level language bindings, use
    * #TpStreamTubeChannel:parameters-vardict or
    * tp_stream_tube_channel_dup_parameters_vardict() to get the same
    * information in a more convenient format.
    *
    * Since: 0.13.2
@@ -1494,7 +1494,7 @@ tp_stream_tube_channel_get_service (TpStreamTubeChannel *self)
 }
 
 /**
- * tp_stream_tube_channel_dup_parameters_vardict:
+ * tp_stream_tube_channel_dup_parameters:
  * @self: a #TpStreamTubeChannel
  *
  * Return the parameters of the dbus-tube channel in a variant of
@@ -1513,7 +1513,7 @@ tp_stream_tube_channel_get_service (TpStreamTubeChannel *self)
  * Since: 0.19.10
  */
 GVariant *
-tp_stream_tube_channel_dup_parameters_vardict (TpStreamTubeChannel *self)
+tp_stream_tube_channel_dup_parameters (TpStreamTubeChannel *self)
 {
   g_return_val_if_fail (TP_IS_STREAM_TUBE_CHANNEL (self), NULL);
 
@@ -453,7 +453,7 @@ tp_stream_tube_channel_class_init (TpStreamTubeChannelClass *klass)
    * In high-level language bindings, use
    * #TpStreamTubeChannel:parameters-vardict or
-   * tp_stream_tube_channel_dup_parameters_vardict() to get the same
+   * tp_stream_tube_channel_dup_parameters() to get the same
    * information in a more convenient format.
    *